==> icinga2_2.2.4.orig.tar.gz: icinga2-2.2.4/lib/livestatus/column.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "livestatus/column.hpp"

using namespace icinga;

Column::Column(const ValueAccessor& valueAccessor, const ObjectAccessor& objectAccessor)
	: m_ValueAccessor(valueAccessor), m_ObjectAccessor(objectAccessor)
{ }

Value Column::ExtractValue(const Value& urow) const
{
	Value row;

	if (!m_ObjectAccessor.empty())
		row = m_ObjectAccessor(urow);
	else
		row = urow;

	return m_ValueAccessor(row);
}

==> icinga2_2.4.1.orig.tar.gz: icinga2-2.4.1/lib/livestatus/column.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "livestatus/column.hpp"

using namespace icinga;

Column::Column(const ValueAccessor& valueAccessor, const ObjectAccessor& objectAccessor)
	: m_ValueAccessor(valueAccessor), m_ObjectAccessor(objectAccessor)
{ }

Value Column::ExtractValue(const Value& urow, LivestatusGroupByType groupByType, const Object::Ptr& groupByObject) const
{
	Value row;

	if (!m_ObjectAccessor.empty())
		row = m_ObjectAccessor(urow, groupByType, groupByObject);
	else
		row = urow;

	return m_ValueAccessor(row);
}
